.\" dpih.d version 1.01 created 09/12/94
.\" by M. P. Wand
.BG
.FN dpih
.TL
Select a Histogram Bin Width 
.DN
Uses direct plug-in methodology to select the bin width of 
a histogram.
.CS
dpih(x, scalest="minim", level=2, gridsize=401, 
     range.x=range(x), truncate=F)
.RA
.AG x
vector containing the sample on which the
histogram is to be constructed.
.OA
.AG scalest
estimate of scale.
.PP
 `"stdev"' - standard deviation is used.
.PP
 `"iqr"' - inter-quartile range divided by 1.349 is used.
.PP
 `"minim"' - minimum of `"stdev"' and `"iqr"' is used.
.AG level
number of levels of functional estimation used in the
plug-in rule.
.AG gridsize
number of grid points used in the binned approximations
to functional estimates.
.AG range.x
range over which functional estimates are obtained.
The default is the minimum and maximum data values.
.AG truncate
if `truncate' is `TRUE' then observations outside
of the interval specified by range.x are omitted.
Otherwise, they are used to weight the extreme grid points.
.RT
the selected bin width.
.DT
The direct plug-in approach, where unknown functionals
that appear in expressions for the asymptotically
optimal bin width and bandwidths
are replaced by kernel estimates, is used.
The normal distribution is used to provide an
initial estimate.
.SH BACKGROUND
This method for selecting the bin width of a histogram is
described in Wand (1995). It is an extension of the
normal scale rule of Scott (1979) and uses plug-in ideas
from bandwidth selection for kernel density estimation
(e.g. Sheather and Jones, 1991).
.SH REFERENCES
Scott, D. W. (1979). 
On optimal and data-based histograms.
.ul
Biometrika, 66, 605-610.
.PP
Sheather, S. J. and Jones, M. C. (1991).
A reliable data-based bandwidth selection method for
kernel density estimation.
.ul
Journal of the Royal Statistical Society, Series B, 53, 683-690. 
.PP
Wand, M. P. (1995).
Data-based choice of histogram binwidth.
.ul
University of New South Wales,
Australian Graduate School of Management 
Working Paper Series No. 95-011.
.SA
`hist'
.EX
x <- geyser$duration
h <- dpih(x)
bins <- seq(min(x)-0.1,max(x)+0.1+h,by=h)
hist(x,breaks=bins)
.KW ~keyword
.WR
